@@ -1,6 +1,7 @@
 """Copyright notice and checks updates."""
 
 import re
+import sys
 from .bouth23 import s
 try:
     from urllib.request import Request
@@ -16,17 +17,30 @@ def check_version():
     try:
         from .__init__ import __version__
 
+        # dont't upgrade if this version of python is not supported anymore
+        import platform
+        implementation = platform.python_implementation()
+        if implementation != "PyPy":
+            pyversion = "py{0}{1}".format(sys.version_info.major,
+                                          sys.version_info.minor)
+        else:
+            pyversion = "pypy"
+
         UA = "isbntools (%s)" % __version__
         headers = {'User-Agent': UA, 'Pragma': 'no-cache'}
         url = "https://raw.githubusercontent.com/xlcnd/"\
               "isbntools/master/isbntools/__init__.py"
-        RE_VERSION = re.compile(r"__version__\s*=\s*'(.*)'")
-
         request = Request(url, headers=headers)
         content = s(urlopen(request).read())
 
-        newversion = re.search(RE_VERSION, content).group(1)
+        RE_SUPPORT = re.compile(r"__support__\s*=\s*'(.*)'")
+        supported = [iden.strip() for iden
+                     in re.search(RE_SUPPORT, content).group(1).split(',')]
+        if pyversion not in supported:
+            raise
 
+        RE_VERSION = re.compile(r"__version__\s*=\s*'(.*)'")
+        newversion = re.search(RE_VERSION, content).group(1)
         if __version__ != newversion:
             print((colors.BOLD + colors.RED))
             print((" ** A new version (%s) is available! **" % newversion))
@@ -39,4 +53,4 @@ def check_version():
     except:
         pass
     finally:
-        print("")
+        sys.exit()
