@@ -1,6 +1,19 @@
 # -*- coding: utf-8 -*-
 """Config file for isbntools."""
 
+# Special files
+CACHE_FILE = '.metacache'
+
+
+# Paths
+CONF_PATH = None
+
+
+def setconfpath(path):
+    """Set the directory of the conf file."""
+    global CONF_PATH
+    CONF_PATH = path
+
 
 # Timeouts
 SOCKETS_TIMEOUT = 12    # seconds
