@@ -3,7 +3,6 @@
 """Private helper functions."""
 
 import re
-import sys
 
 
 def normalize_space(item):
@@ -49,11 +48,6 @@ def unicode_to_utf8tex(utex, filtre=()):
     return regex.sub(lambda m: table[m.group(0)], btex)
 
 
-def in_virtual():
-    """Detect if the program is running inside a python virtual environment."""
-    return True if hasattr(sys, 'real_prefix') else False
-
-
 def cutoff_tokens(tokens, cutoff):
     """Keep only the tokens with total length <= cutoff."""
     ltokens = [len(t) for t in tokens]
