@@ -8,9 +8,9 @@ try:                                 # pragma: no cover
 except ImportError:                  # pragma: no cover
     import ConfigParser as configparser
 import socket
+from . import in_virtual
 from . import config
 from . import registry
-from .dev.lab import in_virtual
 
 # NOTE: THIS CODE RUNS ON IMPORT!
 
@@ -66,6 +66,10 @@ try:
                 os.path.expanduser('~/.local/.isbntools/isbntools.conf'),
                 os.path.expanduser('~/.isbntools/isbntools.conf'),
             ])
+    try:
+        config.setconfpath(os.path.dirname(conf.files[0]))
+    except:
+        pass
 
     if conf.has_section('SYS'):
         # get user defined values for timeouts
